@@ -16,6 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 import {Gtk, Gdk, Gio, GLib, GObject, Adw} from '../dependencies/gi.js';
+import {DesktopWidgetCapability} from '../dependencies/gi.js';
 import {_} from '../dependencies/gettext.js';
 import {DesktopFolderUtils} from '../dependencies/localFiles.js';
 
@@ -153,6 +154,94 @@ const ComboRowWithKey = GObject.registerClass({
     }
 });
 
+const CssOverrideGroup = GObject.registerClass(
+class CssOverrideGroup extends Adw.PreferencesGroup {
+		constructor(params = {}) {
+        super({});
+        this.set_title(_('CSS Override'));
+        this.set_description(_('Customise the appearance of desktop icons with CSS'));
+        const warningLabel = new Gtk.Label();
+        warningLabel.set_markup(
+					'<span style="italic" foreground="red">' +
+						_("Warning: This can break the extension if done incorrectly") +
+						"</span>",
+        );
+        this.add(warningLabel);
+        const icon = Gtk.Image.new_from_icon_name('window-pop-out-symbolic');
+        this.cssOverrideButton = new Adw.ActionRow({
+            title: _('Edit CSS Override File...'),
+        });
+        this.cssOverrideButton.add_suffix(icon);
+        this.cssOverrideButton.set_activatable_widget(icon);
+        this.cssOverrideButton.connect('activated', this.openUserCssOverrideFile.bind(this));
+        this.add(this.cssOverrideButton);
+
+        this.reloadButtonRow = new Adw.ActionRow({
+            title: _('Apply CSS Changes Now'),
+            subtitle: _('Reload the CSS to apply changes immediately'),
+            
+        });
+        const button = Gtk.Button.new_with_label("Reload");
+        button.set_size_request(120, -1);
+        button.set_halign(Gtk.Align.END);
+        button.set_valign(Gtk.Align.CENTER);
+        button.set_hexpand(true);
+        button.set_vexpand(false);
+
+        button.connect('clicked', () => {
+            this.reloadCSS();
+        });
+        this.reloadButtonRow.add_suffix(button);
+        this.reloadButtonRow.set_activatable_widget(button);
+        this.add(this.reloadButtonRow);
+        this.update(params.remoteActions);
+    }
+    
+    reloadCSS() {
+        try {
+            this.remoteActions.activate_action('reloadCSS', null);
+            console.info('CSS reload requested');
+        } catch (e) {
+            console.error(`Failed to reload CSS: ${e}`);
+        }
+    }
+
+    update(remoteActions) {
+        this.remoteActions = remoteActions;
+        if (this.remoteActions?.list_actions()) {
+            this.reloadButtonRow.set_sensitive(true);
+        } else {
+            this.reloadButtonRow.set_sensitive(false);
+        }
+    }
+
+    
+    openUserCssOverrideFile() {
+        const configDir = GLib.get_user_config_dir();
+        const cssFile = Gio.File.new_for_path(
+            GLib.build_filenamev([configDir, appID, 'stylesheet-override.css'])
+        );
+        
+        // Create directory if it doesn't exist
+        const cssDir = cssFile.get_parent();
+        try {
+            cssDir.make_directory_with_parents(null);
+        } catch (e) {
+            // Directory already exists
+        }
+        
+        // Create file if it doesn't exist
+        if (!cssFile.query_exists(null)) {
+            cssFile.create(Gio.FileCreateFlags.NONE, null);
+        }
+        
+        // Open with default text editor
+        const context = Gdk.Display.get_default().get_app_launch_context();
+        context.set_timestamp(Gdk.CURRENT_TIME);
+        Gio.AppInfo.launch_default_for_uri(cssFile.get_uri(), context);
+    }
+});
+
 const ShortcutGroup = GObject.registerClass(
 class ShortcutGroup extends Adw.PreferencesGroup {
     constructor(params = {}) {
@@ -277,7 +366,8 @@ const aboutApp = class AboutDialog {
         );
 
         aboutDialog.set_translator_credits(
-            'Weblate Translators, See History.MD on website.'
+            `Weblate Translators, See History.MD on website. Translated using machine translation with LibreTranslate. Unverified strings, translation may contain errors. Corrections, verification and additional translation can be done on Weblate.
+            Translations available in- ar,az,be,bg,bn,ca,cs,da,de,el,eo,es,et,eu,fa,fi,fr,fur,ga,gl,he,hi,hr,hu,id,it,ja,ka,ko,ky,lv,lt,ms,nb,nb_NO,nl,oc,pl,pt_BR,pt,ro,ru,sk,sl,sq,sv,ta,tl,tr,th,uk,ur,zh-Hans,zh-Hant,zh_CN,zh_TW.`
         );
 
         aboutDialog.set_version(this.version);
@@ -289,7 +379,34 @@ const aboutApp = class AboutDialog {
         );
 
         aboutDialog.set_release_notes(
-            `<p>* Adw version 100.2 for Gnome 45, 46, 47, 48</p>
+            `<p>* Adw version 100.13 for Gnome 45, 46, 47, 48 49</p>
+<ul><li>Adds widgets that can be displayed on the desktop under the icon layer</li></ul>
+<ul><li>Users can apply their own CSS</li></ul>
+            <p>* Adw version 100.11 for Gnome 45, 46, 47, 48 49</p>
+<ul><li>Fix margins in RTL layout under dock</li></ul>
+<ul><li>Adapt to X11 removal in mutter</li></ul>
+            <p>* Adw version 100.9 for Gnome 45, 46, 47, 48 49</p>
+<ul><li>Machine Translation with LibreTranslate to all supported languages</li></ul>
+            <p>* Adw version 100.8-2 for Gnome 45, 46, 47, 48 49</p>
+<ul><li>Bug fix for older gnome versions with no GioUnix namespace</li></ul>
+            <p>* Adw version 100.8 for Gnome 45, 46, 47, 48 49</p>
+<ul><li>Animate margin changes. Respects global Gtk4/Gnome animation settings</li></ul>
+<ul><li>Right long-click brings up gnome shell background menu directly</li></ul>
+<ul><li>Improve search UI, unselected items are now properly dimmed to highlight the selected</li></ul>
+            <p>* Adw version 100.7 for Gnome 45, 46, 47, 48 49</p>
+<ul><li>Fix Gnome 49 compatibility issues</li></ul>
+<ul><li>Fix xdg-terminal-exec directory detection in system data dirs</li></ul>
+            <p>* Adw version 100.6 for Gnome 45, 46, 47, 48 49</p>
+<ul><li>Adapt to new Gnome 49 Meta.Window and Meta.WaylandClient API</li></ul>
+<ul><li>Fix missing app icon if no parent icon folder</li></ul>
+            <p>* Adw version 100.5 for Gnome 45, 46, 47, 48</p>
+<ul><li>Set localized default desktop name</li></ul>
+<ul><li>Resizable open with dialog</li></ul>
+<ul><li>Fix custom icons size</li></ul>
+<ul><li>Update to more direct error message</li></ul>
+            <p>* Adw version 100.3 for Gnome 45, 46, 47, 48</p>
+<ul><li>Draw proper selection rectangle at small sizes</li></ul>
+            <p>* Adw version 100.2 for Gnome 45, 46, 47, 48</p>
 <ul><li>Remove dependency on xdg-user-dirs</li></ul>
             <p>* Adw version 100.1 for Gnome 45, 46, 47, 48</p>
 <p>Minor bug fixes to run on older Adw 1.5, errors on connecting second monitor, fix open terminal shortcut</p>
@@ -430,6 +547,7 @@ const AdwPreferencesWindow = class extends DingPreferencesWindow {
                         appPath
                     );
                     this.shortcutGroup?.update(this.remoteActions);
+                    this.cssOverrideGroup?.update(this.remoteActions);
                 } catch (e) {
                     logError(e, 'Error getting action group');
                 }
@@ -437,6 +555,7 @@ const AdwPreferencesWindow = class extends DingPreferencesWindow {
             (_conn, _name) => {
                 this.remoteActions = null;
                 this.shortcutGroup?.update(this.remoteActions);
+                this.cssOverrideGroup?.update(this.remoteActions);
             }
         );
     }
@@ -525,6 +644,12 @@ const AdwPreferencesWindow = class extends DingPreferencesWindow {
 
         aboutFrame.add(this.shortcutGroup);
 
+        this.cssOverrideGroup = new CssOverrideGroup({
+            remoteActions: this.remoteActions,
+        });
+        this.cssOverrideGroup.set_visible(false); // Initially hidden
+        aboutFrame.add(this.cssOverrideGroup);
+
         const aboutGroup = new Adw.PreferencesGroup();
 
         aboutGroup.set_title('About Adw. Desktop Icons');
@@ -565,15 +690,11 @@ const AdwPreferencesWindow = class extends DingPreferencesWindow {
             Gio.SettingsBindFlags.INVERT_BOOLEAN
         ));
 
-        const dropPlaceRow = this.addActionRowSwitch(this.desktopSettings,
-            'show-drop-place',
-            _('Highlight the drop grid'));
-
-        this.desktopSettings.bind('free-position-icons', dropPlaceRow,
-            'sensitive',
-            Gio.SettingsBindFlags.INVERT_BOOLEAN);
-
-        desktopGroup.add(dropPlaceRow);
+        const showWidgets = this.addActionRowSwitch(this.desktopSettings,
+            'show-desktop-widgets',
+            _('Show desktop widgets'));
+        showWidgets.set_sensitive(DesktopWidgetCapability);
+        desktopGroup.add(showWidgets);
 
         this.desktopFolderGroup
             .add(this.addActionRowButton(_('New Desktop Folder'),
@@ -582,9 +703,11 @@ const AdwPreferencesWindow = class extends DingPreferencesWindow {
                 this.changeDesktop.bind(this)
             ));
 
+        const defaultDesktopPath = this.getSystemLocalizedDesktopDir();
+        const secondarytext = _('Set Desktop back to ~/');
         this.defaultDesktopRow =
             this.addActionRowButton(_('Restore Default Desktop Folder'),
-                _('Set Desktop back to $HOME/Desktop'),
+                `${secondarytext}${defaultDesktopPath}`,
                 _('Restore'),
                 this.restoreDefaultDesktop.bind(this)
             );
@@ -592,6 +715,15 @@ const AdwPreferencesWindow = class extends DingPreferencesWindow {
         this.desktopFolderGroup.add(this.defaultDesktopRow);
         this.defaultDesktopRow.set_sensitive(!this.isDefaultDesktop);
 
+        const dropPlaceRow = this.addActionRowSwitch(this.desktopSettings,
+            'show-drop-place',
+            _('Highlight the drop grid'));
+
+        this.desktopSettings.bind('free-position-icons', dropPlaceRow,
+            'sensitive',
+            Gio.SettingsBindFlags.INVERT_BOOLEAN);
+
+        tweaksGroup.add(dropPlaceRow);
 
         tweaksGroup.add(this.addActionRowSwitch(this.desktopSettings,
             'show-link-emblem',
@@ -673,18 +805,53 @@ const AdwPreferencesWindow = class extends DingPreferencesWindow {
         aboutGroup.add(aboutButton);
 
         const tranlationGroup = new Adw.PreferencesGroup({
-            title: _('Translations'),
-            description: _('All tranlations on Weblate..'),
+            title: _('Translation'),
+            description: _('Machine translated using LibreTranslate. User verified and edited on Weblate.'),
         });
 
         aboutFrame.add(tranlationGroup);
 
-        tranlationGroup.add(this.addActionRowButton(_('Translations'),
-            _('Help translate in your web browser'),
+        tranlationGroup.add(this.addActionRowButton(_('Edit Translations'),
+            _('Verify, add or correct translation in your web browser'),
             _('Translate'),
             this.launchWebTranslation.bind(this)
         ));
 
+        // Track Alt key state using event controllers
+        this._altKeyPressed = false;
+        
+        // Add key event controller to track Alt key
+        const keyController = new Gtk.EventControllerKey();
+        keyController.connect('key-pressed', (controller, keyval, keycode, state) => {
+            if (keyval === Gdk.KEY_Alt_L || keyval === Gdk.KEY_Alt_R) {
+                this._altKeyPressed = true;
+            }
+            return false;
+        });
+        
+        keyController.connect('key-released', (controller, keyval, keycode, state) => {
+            if (keyval === Gdk.KEY_Alt_L || keyval === Gdk.KEY_Alt_R) {
+                this._altKeyPressed = false;
+            }
+        });
+        
+        prefsWindow.add_controller(keyController);
+        
+        // Add click gesture controller to detect Alt+Click on tab
+        const clickController = new Gtk.GestureClick();
+        clickController.connect('pressed', (gesture, n_press, x, y) => {
+            const state = gesture.get_current_event().get_modifier_state();
+            this._altKeyPressed = (state & Gdk.ModifierType.ALT_MASK) !== 0;
+        });
+        prefsWindow.add_controller(clickController);
+        
+        // Show CSS Override group only when navigating to More tab with Alt held
+        prefsWindow.connect('notify::visible-page', () => {
+            if (prefsWindow.get_visible_page() === aboutFrame) {
+                this.cssOverrideGroup.set_visible(this._altKeyPressed);
+            }
+        });
+        
         prefsWindow.set_default_size(600, 650);
 
         this._monitorDesktopDirChanges();
