@@ -90,7 +90,6 @@ const DesktopManager = class {
         this._compositeStackList = null;
         this._displayList = [];
         this.ignoreKeys = this.Enums.IgnoreKeys.map(_k => Gdk[_k]);
-        this.navigationKeys = this.Enums.NavigationKeys.map(_k => Gdk[_k]);
 
         // setup gracefull termination
         if (this._asDesktop) {
@@ -290,7 +289,7 @@ const DesktopManager = class {
                 // clear selection
                 this.unselectAll();
             }
-            this.dragManager.startRubberband(X, Y, shiftPressed, controlPressed);
+            this.dragManager.startRubberband(X, Y);
         }
     }
 
@@ -307,7 +306,7 @@ const DesktopManager = class {
         if (button === 3)
             this.mainApp.activate_action('displayShellBackgroundMenu', null);
     }
-
+    
     onWidgetDisplayChanged() {
         if (this.Prefs.showDesktopWidgets)
             this._startWidgetDisplay();
@@ -324,69 +323,11 @@ const DesktopManager = class {
         this.widgetManager.stopWidgetDisplay();
     }
 
-    _handleKeyboardNavigation(keyval, state) {
-        const isCtrlKey = (state & Gdk.ModifierType.CONTROL_MASK) !== 0;
-        const isShiftKey = (state & Gdk.ModifierType.SHIFT_MASK) !== 0;
-        switch (keyval) {
-        case Gdk.KEY_Left:
-        case Gdk.KEY_Right:
-        case Gdk.KEY_Up:
-        case Gdk.KEY_Down:
-            try {
-                this.desktopActions.isControl = isCtrlKey;
-                this.desktopActions.isShift = isShiftKey;
-
-                let actionName = null;
-                switch (keyval) {
-                case Gdk.KEY_Left: {
-                    actionName = 'chooseIconLeft';
-                    break;
-                }
-                case Gdk.KEY_Right: {
-                    actionName = 'chooseIconRight';
-                    break;
-                }
-                case Gdk.KEY_Up: {
-                    actionName = 'chooseIconUp';
-                    break;
-                }
-                case Gdk.KEY_Down: {
-                    actionName = 'chooseIconDown';
-                    break;
-                }
-                }
-
-                if (actionName) {
-                    this.mainApp.activate_action(actionName, null);
-                    return true;
-                }
-            } finally {
-                // Clean up the temporary flags to avoid surprising state later.
-                this.desktopActions.isControl = undefined;
-                this.desktopActions.isShift = undefined;
-            }
-            break;
-
-        case Gdk.KEY_space:
-            if (isCtrlKey && this.desktopActions._keyboardHoveredItem) {
-                this.dragManager.selected(this.desktopActions._keyboardHoveredItem, this.Enums.Selection.WITH_CONTROL);
-                this.desktopActions._keyboardHoveredItem.setHoveredWithKeyboard();
-                return true;
-            }
-            break;
-        }
-    }
-
-    onKeyPress(keyval, _keycode, state, grid) {
+    onKeyPress(keyval, keycode, state, grid) {
         this.keyEventGrid = grid;
         if (this.popupmenu || this.fileItemMenu.popupmenu)
             return true;
 
-        if (this.navigationKeys.includes(keyval)) {
-            this._handleKeyboardNavigation(keyval, state);
-            return true;
-        }
-
         if (this.ignoreKeys.includes(keyval))
             return true;
 
@@ -1573,8 +1514,6 @@ const DesktopManager = class {
             f.unsetSelected();
             f.opacity = 1;
         });
-        this.desktopActions._keyboardHoveredItem = null;
-        this.dragManager._selectionAnchor = null;
         this.fileItemMenu.activeFileItem = null;
     }
 
