@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-import {Gio, GLib, Gtk, WebKit} from '../dependencies/gi.js';
+import {Gdk, Gio, GLib, Gtk, WebKit} from '../dependencies/gi.js';
 import {_} from '../dependencies/gettext.js';
 import {WidgetRegistry} from '../dependencies/localFiles.js';
 import {HtmlWidgetHost} from '../dependencies/localFiles.js';
@@ -76,10 +76,6 @@ const WidgetManager = class {
         // When true, suppress emitting stateChanged events
         this._suppressStateEvents = false;
 
-        const closeWidget = Gio.SimpleAction.new('closeWidget', null);
-        closeWidget.connect('activate', this.deleteSelectedInstance.bind(this));
-        this._desktopManager.mainApp.add_action(closeWidget);
-
         this._addActions();
 
         this.loadState(this._preferences.widgetState);
@@ -145,6 +141,7 @@ const WidgetManager = class {
         this._rebuildSurfacesFrom(desktops);
         this._detachInstancesWithoutSurface();
         this._reattachAllInstances();
+        this._stopWebkitIfUnneeded();
     }
 
     handleWidgetContainerLayerChange(monitorIndex, onTop) {
@@ -914,7 +911,10 @@ const WidgetManager = class {
         button.set_tooltip_text(_('Add Widget'));
         button.connect(
             'clicked',
-            () => this.openAddWidgetDialog().catch(logError)
+            () => this.openAddWidgetDialog(
+                null,
+                surface.monitorIndex
+            ).catch(logError)
         );
 
         const icon = Gtk.Image.new_from_icon_name('list-add-symbolic');
@@ -1038,6 +1038,11 @@ const WidgetManager = class {
             return;
 
         for (const inst of this._instances.values()) {
+            const surface = this._surfaces.get(inst.monitorIndex);
+
+            if (!surface)
+                continue;
+
             this._ensureInstanceActor(inst);
             this._positionInstanceActor(inst);
         }
@@ -1236,8 +1241,8 @@ const WidgetManager = class {
         }
 
         // Delegate everything to WebWidgetContext
-        this._webWidgetContext
-        .openPreferencesForInstance(selectedId, inst.prefsUri);
+        const webCtx = this._ensureWebWidgetContext();
+        webCtx.openPreferencesForInstance(selectedId, inst.prefsUri);
     }
 
     _raiseInstance(inst) {
@@ -1387,10 +1392,11 @@ const WidgetManager = class {
         if (!this._webWidgetContext)
             return;
 
+        // We prune aggressively, there may be no host, add button has 
+        // no isAlive(). Look only for html hosts
         const hasHtmlWidget =
             Array.from(this._instances.values())
-                .some(inst => inst.actor?.get_first_child?.() instanceof
-                WebKit.WebView);
+                .some(inst => inst.host?.isAlive?.());
 
         if (hasHtmlWidget)
             return;
@@ -1403,7 +1409,7 @@ const WidgetManager = class {
      * Widget Picker UI
      * ===================================================================== */
 
-    async openAddWidgetDialog(parentWindow = null) {
+    async openAddWidgetDialog(parentWindow = null, monitorIndex = null) {
         if (!this._widgetRegistry) {
             console.error('openAddWidgetDialog: widgetRegistry missing');
             return null;
@@ -1446,7 +1452,9 @@ const WidgetManager = class {
 
                 let created = null;
                 try {
-                    created = await this.createInstanceForWidget(row._widgetId);
+                    created = await this.createInstanceForWidget(row._widgetId, {
+                        monitorIndex,
+                    });
                 } catch (e) {
                     console.error(
                         'openAddWidgetDialog: createInstanceForWidget failed:',
@@ -1569,7 +1577,31 @@ const WidgetManager = class {
     _addActions() {
         const addWidgetAction = Gio.SimpleAction.new('addWidget', null);
         addWidgetAction.connect('activate', () => {
-            this.openAddWidgetDialog().catch(logError);
+            // Ensure widget layers are visible before adding a widget.
+            this._desktopManager.windowManager?.raiseWidgetLayers();
+
+            const parentWindow =
+                this._desktopManager.mainApp.get_active_window();
+
+            let monitorIndex = null;
+
+            if (parentWindow) {
+                const surface = parentWindow.get_surface();
+                const display = surface?.get_display?.();
+                const monitor = display?.get_monitor_at_surface?.(surface);
+                const monitors = display?.get_monitors?.();
+                const count = monitors?.get_n_items?.() ?? 0;
+
+                for (let i = 0; i < count; i++) {
+                    if (monitors.get_item?.(i) === monitor) {
+                        monitorIndex = i;
+                        break;
+                    }
+                }
+            }
+
+            this.openAddWidgetDialog(parentWindow, monitorIndex)
+                .catch(logError);
         });
         this._desktopManager.mainApp.add_action(addWidgetAction);
 
